# OrganizationFeatureCategoryExclusion

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**organization_id** | **str** |  | 
**feature_category_id** | **str** |  | 
**organization** | [**Organization**](Organization.md) |  | [optional] 
**feature_category** | [**FeatureCategory**](FeatureCategory.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

